@@ -844,7 +844,7 @@ class Builder(Update):
         Id = 'nvidia-drivers'
         Package = 'x11-drivers/nvidia-drivers'
         Eclass = 'usr/portage/eclass/nvidia-driver.eclass'
-        SkipVers = ('71', '96', '173', '304')
+        SkipVers = ('71', '96', '173', '304', '340')
 
         def generate(self):
             nvidia_eclass = path.join(self.builder_path, self.Eclass)
